import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaAppAttestConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaAppCheckToken(
    typing_extensions.TypedDict, total=False
):
    attestationToken: str
    token: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaAttestationTokenResponse(
    typing_extensions.TypedDict, total=False
):
    attestationToken: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetAppAttestConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaAppAttestConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetDeviceCheckConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaDeviceCheckConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetPlayIntegrityConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaPlayIntegrityConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaRecaptchaConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaEnterpriseConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetRecaptchaV3ConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaRecaptchaV3Config]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchGetSafetyNetConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    configs: _list[GoogleFirebaseAppcheckV1betaSafetyNetConfig]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest(
    typing_extensions.TypedDict, total=False
):
    requests: _list[GoogleFirebaseAppcheckV1betaUpdateServiceRequest]
    updateMask: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaBatchUpdateServicesResponse(
    typing_extensions.TypedDict, total=False
):
    services: _list[GoogleFirebaseAppcheckV1betaService]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaDebugToken(typing_extensions.TypedDict, total=False):
    displayName: str
    name: str
    token: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaDeviceCheckConfig(
    typing_extensions.TypedDict, total=False
):
    keyId: str
    name: str
    privateKey: str
    privateKeySet: bool
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest(
    typing_extensions.TypedDict, total=False
):
    artifact: str
    assertion: str
    challenge: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationRequest(
    typing_extensions.TypedDict, total=False
):
    attestationStatement: str
    challenge: str
    keyId: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeAppAttestAttestationResponse(
    typing_extensions.TypedDict, total=False
):
    appCheckToken: GoogleFirebaseAppcheckV1betaAppCheckToken
    artifact: str
    attestationToken: GoogleFirebaseAppcheckV1betaAttestationTokenResponse

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest(
    typing_extensions.TypedDict, total=False
):
    customToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeDebugTokenRequest(
    typing_extensions.TypedDict, total=False
):
    debugToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeDeviceCheckTokenRequest(
    typing_extensions.TypedDict, total=False
):
    deviceToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangePlayIntegrityTokenRequest(
    typing_extensions.TypedDict, total=False
):
    playIntegrityToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeRecaptchaEnterpriseTokenRequest(
    typing_extensions.TypedDict, total=False
):
    recaptchaEnterpriseToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeRecaptchaTokenRequest(
    typing_extensions.TypedDict, total=False
):
    recaptchaToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeRecaptchaV3TokenRequest(
    typing_extensions.TypedDict, total=False
):
    recaptchaV3Token: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaExchangeSafetyNetTokenRequest(
    typing_extensions.TypedDict, total=False
):
    safetyNetToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGenerateAppAttestChallengeResponse(
    typing_extensions.TypedDict, total=False
):
    challenge: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaGeneratePlayIntegrityChallengeResponse(
    typing_extensions.TypedDict, total=False
):
    challenge: str
    ttl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaListDebugTokensResponse(
    typing_extensions.TypedDict, total=False
):
    debugTokens: _list[GoogleFirebaseAppcheckV1betaDebugToken]
    nextPageToken: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaListServicesResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    services: _list[GoogleFirebaseAppcheckV1betaService]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaPlayIntegrityConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaPublicJwk(typing_extensions.TypedDict, total=False):
    alg: str
    e: str
    kid: str
    kty: str
    n: str
    use: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaPublicJwkSet(
    typing_extensions.TypedDict, total=False
):
    keys: _list[GoogleFirebaseAppcheckV1betaPublicJwk]

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    siteSecret: str
    siteSecretSet: bool
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    siteKey: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaRecaptchaV3Config(
    typing_extensions.TypedDict, total=False
):
    name: str
    siteSecret: str
    siteSecretSet: bool
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaSafetyNetConfig(
    typing_extensions.TypedDict, total=False
):
    name: str
    tokenTtl: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaService(typing_extensions.TypedDict, total=False):
    enforcementMode: typing_extensions.Literal["OFF", "UNENFORCED", "ENFORCED"]
    name: str

@typing.type_check_only
class GoogleFirebaseAppcheckV1betaUpdateServiceRequest(
    typing_extensions.TypedDict, total=False
):
    service: GoogleFirebaseAppcheckV1betaService
    updateMask: str

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FcmdataResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AndroidAppsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DeliveryDataResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponseHttpRequest,
                    previous_response: GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponse,
                ) -> GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponseHttpRequest | None: ...

            def deliveryData(self) -> DeliveryDataResource: ...

        def androidApps(self) -> AndroidAppsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Account(typing_extensions.TypedDict, total=False):
    googleAuto: GoogleAuto

@typing.type_check_only
class AndroidDevice(typing_extensions.TypedDict, total=False):
    androidModelId: str
    androidVersionId: str
    locale: str
    orientation: str

@typing.type_check_only
class AndroidDeviceCatalog(typing_extensions.TypedDict, total=False):
    models: _list[AndroidModel]
    runtimeConfiguration: AndroidRuntimeConfiguration
    versions: _list[AndroidVersion]

@typing.type_check_only
class AndroidDeviceList(typing_extensions.TypedDict, total=False):
    androidDevices: _list[AndroidDevice]

@typing.type_check_only
class AndroidInstrumentationTest(typing_extensions.TypedDict, total=False):
    appApk: FileReference
    appBundle: AppBundle
    appPackageId: str
    orchestratorOption: typing_extensions.Literal[
        "ORCHESTRATOR_OPTION_UNSPECIFIED", "USE_ORCHESTRATOR", "DO_NOT_USE_ORCHESTRATOR"
    ]
    shardingOption: ShardingOption
    testApk: FileReference
    testPackageId: str
    testRunnerClass: str
    testTargets: _list[str]

@typing.type_check_only
class AndroidMatrix(typing_extensions.TypedDict, total=False):
    androidModelIds: _list[str]
    androidVersionIds: _list[str]
    locales: _list[str]
    orientations: _list[str]

@typing.type_check_only
class AndroidModel(typing_extensions.TypedDict, total=False):
    brand: str
    codename: str
    form: typing_extensions.Literal[
        "DEVICE_FORM_UNSPECIFIED", "VIRTUAL", "PHYSICAL", "EMULATOR"
    ]
    formFactor: typing_extensions.Literal[
        "DEVICE_FORM_FACTOR_UNSPECIFIED", "PHONE", "TABLET", "WEARABLE"
    ]
    id: str
    lowFpsVideoRecording: bool
    manufacturer: str
    name: str
    screenDensity: int
    screenX: int
    screenY: int
    supportedAbis: _list[str]
    supportedVersionIds: _list[str]
    tags: _list[str]
    thumbnailUrl: str

@typing.type_check_only
class AndroidRoboTest(typing_extensions.TypedDict, total=False):
    appApk: FileReference
    appBundle: AppBundle
    appInitialActivity: str
    appPackageId: str
    maxDepth: int
    maxSteps: int
    roboDirectives: _list[RoboDirective]
    roboMode: typing_extensions.Literal[
        "ROBO_MODE_UNSPECIFIED", "ROBO_VERSION_1", "ROBO_VERSION_2"
    ]
    roboScript: FileReference
    startingIntents: _list[RoboStartingIntent]

@typing.type_check_only
class AndroidRuntimeConfiguration(typing_extensions.TypedDict, total=False):
    locales: _list[Locale]
    orientations: _list[Orientation]

@typing.type_check_only
class AndroidTestLoop(typing_extensions.TypedDict, total=False):
    appApk: FileReference
    appBundle: AppBundle
    appPackageId: str
    scenarioLabels: _list[str]
    scenarios: _list[int]

@typing.type_check_only
class AndroidVersion(typing_extensions.TypedDict, total=False):
    apiLevel: int
    codeName: str
    distribution: Distribution
    id: str
    releaseDate: Date
    tags: _list[str]
    versionString: str

@typing.type_check_only
class Apk(typing_extensions.TypedDict, total=False):
    location: FileReference
    packageName: str

@typing.type_check_only
class ApkDetail(typing_extensions.TypedDict, total=False):
    apkManifest: ApkManifest

@typing.type_check_only
class ApkManifest(typing_extensions.TypedDict, total=False):
    applicationLabel: str
    intentFilters: _list[IntentFilter]
    maxSdkVersion: int
    minSdkVersion: int
    packageName: str
    targetSdkVersion: int
    usesPermission: _list[str]
    versionCode: str
    versionName: str

@typing.type_check_only
class AppBundle(typing_extensions.TypedDict, total=False):
    bundleLocation: FileReference

@typing.type_check_only
class CancelTestMatrixResponse(typing_extensions.TypedDict, total=False):
    testState: typing_extensions.Literal[
        "TEST_STATE_UNSPECIFIED",
        "VALIDATING",
        "PENDING",
        "RUNNING",
        "FINISHED",
        "ERROR",
        "UNSUPPORTED_ENVIRONMENT",
        "INCOMPATIBLE_ENVIRONMENT",
        "INCOMPATIBLE_ARCHITECTURE",
        "CANCELLED",
        "INVALID",
    ]

@typing.type_check_only
class ClientInfo(typing_extensions.TypedDict, total=False):
    clientInfoDetails: _list[ClientInfoDetail]
    name: str

@typing.type_check_only
class ClientInfoDetail(typing_extensions.TypedDict, total=False):
    key: str
    value: str

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DeviceFile(typing_extensions.TypedDict, total=False):
    obbFile: ObbFile
    regularFile: RegularFile

@typing.type_check_only
class DeviceIpBlock(typing_extensions.TypedDict, total=False):
    addedDate: Date
    block: str
    form: typing_extensions.Literal[
        "DEVICE_FORM_UNSPECIFIED", "VIRTUAL", "PHYSICAL", "EMULATOR"
    ]

@typing.type_check_only
class DeviceIpBlockCatalog(typing_extensions.TypedDict, total=False):
    ipBlocks: _list[DeviceIpBlock]

@typing.type_check_only
class Distribution(typing_extensions.TypedDict, total=False):
    marketShare: float
    measurementTime: str

@typing.type_check_only
class Environment(typing_extensions.TypedDict, total=False):
    androidDevice: AndroidDevice
    iosDevice: IosDevice

@typing.type_check_only
class EnvironmentMatrix(typing_extensions.TypedDict, total=False):
    androidDeviceList: AndroidDeviceList
    androidMatrix: AndroidMatrix
    iosDeviceList: IosDeviceList

@typing.type_check_only
class EnvironmentVariable(typing_extensions.TypedDict, total=False):
    key: str
    value: str

@typing.type_check_only
class FileReference(typing_extensions.TypedDict, total=False):
    gcsPath: str

@typing.type_check_only
class GetApkDetailsResponse(typing_extensions.TypedDict, total=False):
    apkDetail: ApkDetail

@typing.type_check_only
class GoogleAuto(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleCloudStorage(typing_extensions.TypedDict, total=False):
    gcsPath: str

@typing.type_check_only
class IntentFilter(typing_extensions.TypedDict, total=False):
    actionNames: _list[str]
    categoryNames: _list[str]
    mimeType: str

@typing.type_check_only
class IosDevice(typing_extensions.TypedDict, total=False):
    iosModelId: str
    iosVersionId: str
    locale: str
    orientation: str

@typing.type_check_only
class IosDeviceCatalog(typing_extensions.TypedDict, total=False):
    models: _list[IosModel]
    runtimeConfiguration: IosRuntimeConfiguration
    versions: _list[IosVersion]
    xcodeVersions: _list[XcodeVersion]

@typing.type_check_only
class IosDeviceFile(typing_extensions.TypedDict, total=False):
    bundleId: str
    content: FileReference
    devicePath: str

@typing.type_check_only
class IosDeviceList(typing_extensions.TypedDict, total=False):
    iosDevices: _list[IosDevice]

@typing.type_check_only
class IosModel(typing_extensions.TypedDict, total=False):
    deviceCapabilities: _list[str]
    formFactor: typing_extensions.Literal[
        "DEVICE_FORM_FACTOR_UNSPECIFIED", "PHONE", "TABLET", "WEARABLE"
    ]
    id: str
    name: str
    screenDensity: int
    screenX: int
    screenY: int
    supportedVersionIds: _list[str]
    tags: _list[str]

@typing.type_check_only
class IosRuntimeConfiguration(typing_extensions.TypedDict, total=False):
    locales: _list[Locale]
    orientations: _list[Orientation]

@typing.type_check_only
class IosTestLoop(typing_extensions.TypedDict, total=False):
    appBundleId: str
    appIpa: FileReference
    scenarios: _list[int]

@typing.type_check_only
class IosTestSetup(typing_extensions.TypedDict, total=False):
    additionalIpas: _list[FileReference]
    networkProfile: str
    pullDirectories: _list[IosDeviceFile]
    pushFiles: _list[IosDeviceFile]

@typing.type_check_only
class IosVersion(typing_extensions.TypedDict, total=False):
    id: str
    majorVersion: int
    minorVersion: int
    supportedXcodeVersionIds: _list[str]
    tags: _list[str]

@typing.type_check_only
class IosXcTest(typing_extensions.TypedDict, total=False):
    appBundleId: str
    testSpecialEntitlements: bool
    testsZip: FileReference
    xcodeVersion: str
    xctestrun: FileReference

@typing.type_check_only
class LauncherActivityIntent(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Locale(typing_extensions.TypedDict, total=False):
    id: str
    name: str
    region: str
    tags: _list[str]

@typing.type_check_only
class ManualSharding(typing_extensions.TypedDict, total=False):
    testTargetsForShard: _list[TestTargetsForShard]

@typing.type_check_only
class NetworkConfiguration(typing_extensions.TypedDict, total=False):
    downRule: TrafficRule
    id: str
    upRule: TrafficRule

@typing.type_check_only
class NetworkConfigurationCatalog(typing_extensions.TypedDict, total=False):
    configurations: _list[NetworkConfiguration]

@typing.type_check_only
class ObbFile(typing_extensions.TypedDict, total=False):
    obb: FileReference
    obbFileName: str

@typing.type_check_only
class Orientation(typing_extensions.TypedDict, total=False):
    id: str
    name: str
    tags: _list[str]

@typing.type_check_only
class ProvidedSoftwareCatalog(typing_extensions.TypedDict, total=False):
    androidxOrchestratorVersion: str
    orchestratorVersion: str

@typing.type_check_only
class RegularFile(typing_extensions.TypedDict, total=False):
    content: FileReference
    devicePath: str

@typing.type_check_only
class ResultStorage(typing_extensions.TypedDict, total=False):
    googleCloudStorage: GoogleCloudStorage
    resultsUrl: str
    toolResultsExecution: ToolResultsExecution
    toolResultsHistory: ToolResultsHistory

@typing.type_check_only
class RoboDirective(typing_extensions.TypedDict, total=False):
    actionType: typing_extensions.Literal[
        "ACTION_TYPE_UNSPECIFIED", "SINGLE_CLICK", "ENTER_TEXT", "IGNORE"
    ]
    inputText: str
    resourceName: str

@typing.type_check_only
class RoboStartingIntent(typing_extensions.TypedDict, total=False):
    launcherActivity: LauncherActivityIntent
    startActivity: StartActivityIntent
    timeout: str

@typing.type_check_only
class Shard(typing_extensions.TypedDict, total=False):
    numShards: int
    shardIndex: int
    testTargetsForShard: TestTargetsForShard

@typing.type_check_only
class ShardingOption(typing_extensions.TypedDict, total=False):
    manualSharding: ManualSharding
    uniformSharding: UniformSharding

@typing.type_check_only
class StartActivityIntent(typing_extensions.TypedDict, total=False):
    action: str
    categories: _list[str]
    uri: str

@typing.type_check_only
class SystraceSetup(typing_extensions.TypedDict, total=False):
    durationSeconds: int

@typing.type_check_only
class TestDetails(typing_extensions.TypedDict, total=False):
    errorMessage: str
    progressMessages: _list[str]

@typing.type_check_only
class TestEnvironmentCatalog(typing_extensions.TypedDict, total=False):
    androidDeviceCatalog: AndroidDeviceCatalog
    deviceIpBlockCatalog: DeviceIpBlockCatalog
    iosDeviceCatalog: IosDeviceCatalog
    networkConfigurationCatalog: NetworkConfigurationCatalog
    softwareCatalog: ProvidedSoftwareCatalog

@typing.type_check_only
class TestExecution(typing_extensions.TypedDict, total=False):
    environment: Environment
    id: str
    matrixId: str
    projectId: str
    shard: Shard
    state: typing_extensions.Literal[
        "TEST_STATE_UNSPECIFIED",
        "VALIDATING",
        "PENDING",
        "RUNNING",
        "FINISHED",
        "ERROR",
        "UNSUPPORTED_ENVIRONMENT",
        "INCOMPATIBLE_ENVIRONMENT",
        "INCOMPATIBLE_ARCHITECTURE",
        "CANCELLED",
        "INVALID",
    ]
    testDetails: TestDetails
    testSpecification: TestSpecification
    timestamp: str
    toolResultsStep: ToolResultsStep

@typing.type_check_only
class TestMatrix(typing_extensions.TypedDict, total=False):
    clientInfo: ClientInfo
    environmentMatrix: EnvironmentMatrix
    failFast: bool
    flakyTestAttempts: int
    invalidMatrixDetails: typing_extensions.Literal[
        "INVALID_MATRIX_DETAILS_UNSPECIFIED",
        "DETAILS_UNAVAILABLE",
        "MALFORMED_APK",
        "MALFORMED_TEST_APK",
        "NO_MANIFEST",
        "NO_PACKAGE_NAME",
        "INVALID_PACKAGE_NAME",
        "TEST_SAME_AS_APP",
        "NO_INSTRUMENTATION",
        "NO_SIGNATURE",
        "INSTRUMENTATION_ORCHESTRATOR_INCOMPATIBLE",
        "NO_TEST_RUNNER_CLASS",
        "NO_LAUNCHER_ACTIVITY",
        "FORBIDDEN_PERMISSIONS",
        "INVALID_ROBO_DIRECTIVES",
        "INVALID_RESOURCE_NAME",
        "INVALID_DIRECTIVE_ACTION",
        "TEST_LOOP_INTENT_FILTER_NOT_FOUND",
        "SCENARIO_LABEL_NOT_DECLARED",
        "SCENARIO_LABEL_MALFORMED",
        "SCENARIO_NOT_DECLARED",
        "DEVICE_ADMIN_RECEIVER",
        "MALFORMED_XC_TEST_ZIP",
        "BUILT_FOR_IOS_SIMULATOR",
        "NO_TESTS_IN_XC_TEST_ZIP",
        "USE_DESTINATION_ARTIFACTS",
        "TEST_NOT_APP_HOSTED",
        "PLIST_CANNOT_BE_PARSED",
        "TEST_ONLY_APK",
        "MALFORMED_IPA",
        "MISSING_URL_SCHEME",
        "MALFORMED_APP_BUNDLE",
        "NO_CODE_APK",
        "INVALID_INPUT_APK",
        "INVALID_APK_PREVIEW_SDK",
    ]
    outcomeSummary: typing_extensions.Literal[
        "OUTCOME_SUMMARY_UNSPECIFIED", "SUCCESS", "FAILURE", "INCONCLUSIVE", "SKIPPED"
    ]
    projectId: str
    resultStorage: ResultStorage
    state: typing_extensions.Literal[
        "TEST_STATE_UNSPECIFIED",
        "VALIDATING",
        "PENDING",
        "RUNNING",
        "FINISHED",
        "ERROR",
        "UNSUPPORTED_ENVIRONMENT",
        "INCOMPATIBLE_ENVIRONMENT",
        "INCOMPATIBLE_ARCHITECTURE",
        "CANCELLED",
        "INVALID",
    ]
    testExecutions: _list[TestExecution]
    testMatrixId: str
    testSpecification: TestSpecification
    timestamp: str

@typing.type_check_only
class TestSetup(typing_extensions.TypedDict, total=False):
    account: Account
    additionalApks: _list[Apk]
    directoriesToPull: _list[str]
    dontAutograntPermissions: bool
    environmentVariables: _list[EnvironmentVariable]
    filesToPush: _list[DeviceFile]
    networkProfile: str
    systrace: SystraceSetup

@typing.type_check_only
class TestSpecification(typing_extensions.TypedDict, total=False):
    androidInstrumentationTest: AndroidInstrumentationTest
    androidRoboTest: AndroidRoboTest
    androidTestLoop: AndroidTestLoop
    disablePerformanceMetrics: bool
    disableVideoRecording: bool
    iosTestLoop: IosTestLoop
    iosTestSetup: IosTestSetup
    iosXcTest: IosXcTest
    testSetup: TestSetup
    testTimeout: str

@typing.type_check_only
class TestTargetsForShard(typing_extensions.TypedDict, total=False):
    testTargets: _list[str]

@typing.type_check_only
class ToolResultsExecution(typing_extensions.TypedDict, total=False):
    executionId: str
    historyId: str
    projectId: str

@typing.type_check_only
class ToolResultsHistory(typing_extensions.TypedDict, total=False):
    historyId: str
    projectId: str

@typing.type_check_only
class ToolResultsStep(typing_extensions.TypedDict, total=False):
    executionId: str
    historyId: str
    projectId: str
    stepId: str

@typing.type_check_only
class TrafficRule(typing_extensions.TypedDict, total=False):
    bandwidth: float
    burst: float
    delay: str
    packetDuplicationRatio: float
    packetLossRatio: float

@typing.type_check_only
class UniformSharding(typing_extensions.TypedDict, total=False):
    numShards: int

@typing.type_check_only
class XcodeVersion(typing_extensions.TypedDict, total=False):
    tags: _list[str]
    version: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ActingUser(typing_extensions.TypedDict, total=False):
    email: str
    imageUrl: str

@typing.type_check_only
class CertDnsChallenge(typing_extensions.TypedDict, total=False):
    domainName: str
    token: str

@typing.type_check_only
class CertHttpChallenge(typing_extensions.TypedDict, total=False):
    path: str
    token: str

@typing.type_check_only
class Channel(typing_extensions.TypedDict, total=False):
    createTime: str
    expireTime: str
    labels: dict[str, typing.Any]
    name: str
    release: Release
    retainedReleaseCount: int
    ttl: str
    updateTime: str
    url: str

@typing.type_check_only
class CloneVersionRequest(typing_extensions.TypedDict, total=False):
    exclude: PathFilter
    finalize: bool
    include: PathFilter
    sourceVersion: str

@typing.type_check_only
class CloudRunRewrite(typing_extensions.TypedDict, total=False):
    region: str
    serviceId: str

@typing.type_check_only
class Domain(typing_extensions.TypedDict, total=False):
    domainName: str
    domainRedirect: DomainRedirect
    provisioning: DomainProvisioning
    site: str
    status: typing_extensions.Literal[
        "DOMAIN_STATUS_UNSPECIFIED",
        "DOMAIN_CHANGE_PENDING",
        "DOMAIN_ACTIVE",
        "DOMAIN_VERIFICATION_REQUIRED",
        "DOMAIN_VERIFICATION_LOST",
    ]
    updateTime: str

@typing.type_check_only
class DomainProvisioning(typing_extensions.TypedDict, total=False):
    certChallengeDiscoveredTxt: _list[str]
    certChallengeDns: CertDnsChallenge
    certChallengeHttp: CertHttpChallenge
    certStatus: typing_extensions.Literal[
        "CERT_STATUS_UNSPECIFIED",
        "CERT_PENDING",
        "CERT_MISSING",
        "CERT_PROCESSING",
        "CERT_PROPAGATING",
        "CERT_ACTIVE",
        "CERT_ERROR",
    ]
    discoveredIps: _list[str]
    dnsFetchTime: str
    dnsStatus: typing_extensions.Literal[
        "DNS_STATUS_UNSPECIFIED",
        "DNS_PENDING",
        "DNS_MISSING",
        "DNS_PARTIAL_MATCH",
        "DNS_MATCH",
        "DNS_EXTRANEOUS_MATCH",
    ]
    expectedIps: _list[str]

@typing.type_check_only
class DomainRedirect(typing_extensions.TypedDict, total=False):
    domainName: str
    type: typing_extensions.Literal["REDIRECT_TYPE_UNSPECIFIED", "MOVED_PERMANENTLY"]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Header(typing_extensions.TypedDict, total=False):
    glob: str
    headers: dict[str, typing.Any]
    regex: str

@typing.type_check_only
class I18nConfig(typing_extensions.TypedDict, total=False):
    root: str

@typing.type_check_only
class ListChannelsResponse(typing_extensions.TypedDict, total=False):
    channels: _list[Channel]
    nextPageToken: str

@typing.type_check_only
class ListDomainsResponse(typing_extensions.TypedDict, total=False):
    domains: _list[Domain]
    nextPageToken: str

@typing.type_check_only
class ListReleasesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    releases: _list[Release]

@typing.type_check_only
class ListSitesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    sites: _list[Site]

@typing.type_check_only
class ListVersionFilesResponse(typing_extensions.TypedDict, total=False):
    files: _list[VersionFile]
    nextPageToken: str

@typing.type_check_only
class ListVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    versions: _list[Version]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class PathFilter(typing_extensions.TypedDict, total=False):
    regexes: _list[str]

@typing.type_check_only
class PopulateVersionFilesRequest(typing_extensions.TypedDict, total=False):
    files: dict[str, typing.Any]

@typing.type_check_only
class PopulateVersionFilesResponse(typing_extensions.TypedDict, total=False):
    uploadRequiredHashes: _list[str]
    uploadUrl: str

@typing.type_check_only
class Redirect(typing_extensions.TypedDict, total=False):
    glob: str
    location: str
    regex: str
    statusCode: int

@typing.type_check_only
class Release(typing_extensions.TypedDict, total=False):
    message: str
    name: str
    releaseTime: str
    releaseUser: ActingUser
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "DEPLOY", "ROLLBACK", "SITE_DISABLE"
    ]
    version: Version

@typing.type_check_only
class Rewrite(typing_extensions.TypedDict, total=False):
    dynamicLinks: bool
    function: str
    functionRegion: str
    glob: str
    path: str
    regex: str
    run: CloudRunRewrite

@typing.type_check_only
class ServingConfig(typing_extensions.TypedDict, total=False):
    appAssociation: typing_extensions.Literal["AUTO", "NONE"]
    cleanUrls: bool
    headers: _list[Header]
    i18n: I18nConfig
    redirects: _list[Redirect]
    rewrites: _list[Rewrite]
    trailingSlashBehavior: typing_extensions.Literal[
        "TRAILING_SLASH_BEHAVIOR_UNSPECIFIED", "ADD", "REMOVE"
    ]

@typing.type_check_only
class Site(typing_extensions.TypedDict, total=False):
    appId: str
    defaultUrl: str
    labels: dict[str, typing.Any]
    name: str
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "DEFAULT_SITE", "USER_SITE"]

@typing.type_check_only
class SiteConfig(typing_extensions.TypedDict, total=False):
    cloudLoggingEnabled: bool
    maxVersions: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class Version(typing_extensions.TypedDict, total=False):
    config: ServingConfig
    createTime: str
    createUser: ActingUser
    deleteTime: str
    deleteUser: ActingUser
    fileCount: str
    finalizeTime: str
    finalizeUser: ActingUser
    labels: dict[str, typing.Any]
    name: str
    status: typing_extensions.Literal[
        "VERSION_STATUS_UNSPECIFIED",
        "CREATED",
        "FINALIZED",
        "DELETED",
        "ABANDONED",
        "EXPIRED",
        "CLONING",
    ]
    versionBytes: str

@typing.type_check_only
class VersionFile(typing_extensions.TypedDict, total=False):
    hash: str
    path: str
    status: typing_extensions.Literal["STATUS_UNSPECIFIED", "EXPECTED", "ACTIVE"]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Attributes(typing_extensions.TypedDict, total=False):
    additionalImageLink: _list[Image]
    ageGroup: str
    brand: str
    capacity: Capacity
    color: str
    count: Count
    description: str
    disclosureDate: str
    excludedDestination: _list[str]
    featureDescription: _list[FeatureDescription]
    flavor: str
    format: str
    gender: str
    grocery: Grocery
    gtin: _list[str]
    imageLink: Image
    includedDestination: _list[str]
    itemGroupId: str
    material: str
    mpn: str
    nutrition: Nutrition
    pattern: str
    productDetail: _list[ProductDetail]
    productHighlight: _list[str]
    productLine: str
    productName: str
    productPageUrl: str
    productType: _list[str]
    releaseDate: str
    richProductContent: _list[str]
    scent: str
    size: str
    sizeSystem: str
    sizeType: _list[str]
    suggestedRetailPrice: Price
    targetClientId: str
    theme: str
    title: str
    videoLink: _list[str]

@typing.type_check_only
class Capacity(typing_extensions.TypedDict, total=False):
    unit: str
    value: str

@typing.type_check_only
class Count(typing_extensions.TypedDict, total=False):
    unit: str
    value: str

@typing.type_check_only
class DestinationStatus(typing_extensions.TypedDict, total=False):
    destination: str
    status: typing_extensions.Literal["UNKNOWN", "ACTIVE", "PENDING", "DISAPPROVED"]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FeatureDescription(typing_extensions.TypedDict, total=False):
    headline: str
    image: Image
    text: str

@typing.type_check_only
class FloatUnit(typing_extensions.TypedDict, total=False):
    amount: float
    unit: str

@typing.type_check_only
class Grocery(typing_extensions.TypedDict, total=False):
    activeIngredients: str
    alcoholByVolume: float
    allergens: str
    derivedNutritionClaim: _list[str]
    directions: str
    indications: str
    ingredients: str
    nutritionClaim: _list[str]
    storageInstructions: str

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    imageUrl: str
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "PENDING_PROCESSING",
        "PENDING_CRAWL",
        "OK",
        "ROBOTED",
        "XROBOTED",
        "CRAWL_ERROR",
        "PROCESSING_ERROR",
        "DECODING_ERROR",
        "TOO_BIG",
        "CRAWL_SKIPPED",
        "HOSTLOADED",
        "HTTP_404",
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "CRAWLED", "UPLOADED"]

@typing.type_check_only
class Issue(typing_extensions.TypedDict, total=False):
    attribute: str
    description: str
    destination: str
    resolution: typing_extensions.Literal[
        "RESOLUTION_UNSPECIFIED", "USER_ACTION", "PENDING_PROCESSING"
    ]
    severity: typing_extensions.Literal[
        "SEVERITY_UNSPECIFIED", "ERROR", "WARNING", "INFO"
    ]
    timestamp: str
    title: str
    type: str

@typing.type_check_only
class ListProductsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    products: _list[Product]

@typing.type_check_only
class Nutrition(typing_extensions.TypedDict, total=False):
    addedSugars: FloatUnit
    addedSugarsDailyPercentage: float
    calcium: FloatUnit
    calciumDailyPercentage: float
    cholesterol: FloatUnit
    cholesterolDailyPercentage: float
    dietaryFiber: FloatUnit
    dietaryFiberDailyPercentage: float
    energy: FloatUnit
    energyFromFat: FloatUnit
    folateDailyPercentage: float
    folateFolicAcid: FloatUnit
    folateMcgDfe: float
    iron: FloatUnit
    ironDailyPercentage: float
    monounsaturatedFat: FloatUnit
    nutritionFactMeasure: str
    polyols: FloatUnit
    polyunsaturatedFat: FloatUnit
    potassium: FloatUnit
    potassiumDailyPercentage: float
    preparedSizeDescription: str
    protein: FloatUnit
    proteinDailyPercentage: float
    saturatedFat: FloatUnit
    saturatedFatDailyPercentage: float
    servingSizeDescription: str
    servingSizeMeasure: FloatUnit
    servingsPerContainer: str
    sodium: FloatUnit
    sodiumDailyPercentage: float
    starch: FloatUnit
    totalCarbohydrate: FloatUnit
    totalCarbohydrateDailyPercentage: float
    totalFat: FloatUnit
    totalFatDailyPercentage: float
    totalSugars: FloatUnit
    totalSugarsDailyPercentage: float
    transFat: FloatUnit
    transFatDailyPercentage: float
    vitaminD: FloatUnit
    vitaminDDailyPercentage: float
    voluntaryNutritionFact: _list[VoluntaryNutritionFact]

@typing.type_check_only
class Price(typing_extensions.TypedDict, total=False):
    amount: str
    currency: str

@typing.type_check_only
class Product(typing_extensions.TypedDict, total=False):
    attributes: Attributes
    contentLanguage: str
    destinationStatuses: _list[DestinationStatus]
    issues: _list[Issue]
    name: str
    parent: str
    productId: str
    targetCountry: str

@typing.type_check_only
class ProductDetail(typing_extensions.TypedDict, total=False):
    attributeName: str
    attributeValue: str
    sectionName: str

@typing.type_check_only
class VoluntaryNutritionFact(typing_extensions.TypedDict, total=False):
    dailyPercentage: float
    name: str
    value: FloatUnit



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class VMMigrationServiceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GroupsResource(googleapiclient.discovery.Resource):
                def addGroupMigration(
                    self,
                    *,
                    group: str,
                    body: AddGroupMigrationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: Group = ...,
                    groupId: str = ...,
                    requestId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GroupHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListGroupsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListGroupsResponseHttpRequest,
                    previous_response: ListGroupsResponse,
                ) -> ListGroupsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Group = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def removeGroupMigration(
                    self,
                    *,
                    group: str,
                    body: RemoveGroupMigrationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class SourcesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class DatacenterConnectorsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: DatacenterConnector = ...,
                        datacenterConnectorId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> DatacenterConnectorHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListDatacenterConnectorsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListDatacenterConnectorsResponseHttpRequest,
                        previous_response: ListDatacenterConnectorsResponse,
                    ) -> ListDatacenterConnectorsResponseHttpRequest | None: ...
                    def upgradeAppliance(
                        self,
                        *,
                        datacenterConnector: str,
                        body: UpgradeApplianceRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class MigratingVmsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class CloneJobsResource(googleapiclient.discovery.Resource):
                        def cancel(
                            self,
                            *,
                            name: str,
                            body: CancelCloneJobRequest = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def create(
                            self,
                            *,
                            parent: str,
                            body: CloneJob = ...,
                            cloneJobId: str = ...,
                            requestId: str = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> CloneJobHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            orderBy: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListCloneJobsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListCloneJobsResponseHttpRequest,
                            previous_response: ListCloneJobsResponse,
                        ) -> ListCloneJobsResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class CutoverJobsResource(googleapiclient.discovery.Resource):
                        def cancel(
                            self,
                            *,
                            name: str,
                            body: CancelCutoverJobRequest = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def create(
                            self,
                            *,
                            parent: str,
                            body: CutoverJob = ...,
                            cutoverJobId: str = ...,
                            requestId: str = ...,
                            **kwargs: typing.Any
                        ) -> OperationHttpRequest: ...
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> CutoverJobHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            orderBy: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListCutoverJobsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListCutoverJobsResponseHttpRequest,
                            previous_response: ListCutoverJobsResponse,
                        ) -> ListCutoverJobsResponseHttpRequest | None: ...

                    @typing.type_check_only
                    class ReplicationCyclesResource(googleapiclient.discovery.Resource):
                        def get(
                            self, *, name: str, **kwargs: typing.Any
                        ) -> ReplicationCycleHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            filter: str = ...,
                            orderBy: str = ...,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            **kwargs: typing.Any
                        ) -> ListReplicationCyclesResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListReplicationCyclesResponseHttpRequest,
                            previous_response: ListReplicationCyclesResponse,
                        ) -> ListReplicationCyclesResponseHttpRequest | None: ...

                    def create(
                        self,
                        *,
                        parent: str,
                        body: MigratingVm = ...,
                        migratingVmId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def finalizeMigration(
                        self,
                        *,
                        migratingVm: str,
                        body: FinalizeMigrationRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self,
                        *,
                        name: str,
                        view: typing_extensions.Literal[
                            "MIGRATING_VM_VIEW_UNSPECIFIED",
                            "MIGRATING_VM_VIEW_BASIC",
                            "MIGRATING_VM_VIEW_FULL",
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> MigratingVmHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        view: typing_extensions.Literal[
                            "MIGRATING_VM_VIEW_UNSPECIFIED",
                            "MIGRATING_VM_VIEW_BASIC",
                            "MIGRATING_VM_VIEW_FULL",
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> ListMigratingVmsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListMigratingVmsResponseHttpRequest,
                        previous_response: ListMigratingVmsResponse,
                    ) -> ListMigratingVmsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: MigratingVm = ...,
                        requestId: str = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def pauseMigration(
                        self,
                        *,
                        migratingVm: str,
                        body: PauseMigrationRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def resumeMigration(
                        self,
                        *,
                        migratingVm: str,
                        body: ResumeMigrationRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def startMigration(
                        self,
                        *,
                        migratingVm: str,
                        body: StartMigrationRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def cloneJobs(self) -> CloneJobsResource: ...
                    def cutoverJobs(self) -> CutoverJobsResource: ...
                    def replicationCycles(self) -> ReplicationCyclesResource: ...

                @typing.type_check_only
                class UtilizationReportsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: UtilizationReport = ...,
                        requestId: str = ...,
                        utilizationReportId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self,
                        *,
                        name: str,
                        view: typing_extensions.Literal[
                            "UTILIZATION_REPORT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> UtilizationReportHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        view: typing_extensions.Literal[
                            "UTILIZATION_REPORT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                        ] = ...,
                        **kwargs: typing.Any
                    ) -> ListUtilizationReportsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListUtilizationReportsResponseHttpRequest,
                        previous_response: ListUtilizationReportsResponse,
                    ) -> ListUtilizationReportsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Source = ...,
                    requestId: str = ...,
                    sourceId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def fetchInventory(
                    self,
                    *,
                    source: str,
                    forceRefresh: bool = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> FetchInventoryResponseHttpRequest: ...
                def fetchInventory_next(
                    self,
                    previous_request: FetchInventoryResponseHttpRequest,
                    previous_response: FetchInventoryResponse,
                ) -> FetchInventoryResponseHttpRequest | None: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> SourceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListSourcesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListSourcesResponseHttpRequest,
                    previous_response: ListSourcesResponse,
                ) -> ListSourcesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Source = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def datacenterConnectors(self) -> DatacenterConnectorsResource: ...
                def migratingVms(self) -> MigratingVmsResource: ...
                def utilizationReports(self) -> UtilizationReportsResource: ...

            @typing.type_check_only
            class TargetProjectsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: TargetProject = ...,
                    requestId: str = ...,
                    targetProjectId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TargetProjectHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTargetProjectsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTargetProjectsResponseHttpRequest,
                    previous_response: ListTargetProjectsResponse,
                ) -> ListTargetProjectsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: TargetProject = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def groups(self) -> GroupsResource: ...
            def operations(self) -> OperationsResource: ...
            def sources(self) -> SourcesResource: ...
            def targetProjects(self) -> TargetProjectsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class CloneJobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CloneJob: ...

@typing.type_check_only
class CutoverJobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CutoverJob: ...

@typing.type_check_only
class DatacenterConnectorHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatacenterConnector: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FetchInventoryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FetchInventoryResponse: ...

@typing.type_check_only
class GroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Group: ...

@typing.type_check_only
class ListCloneJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCloneJobsResponse: ...

@typing.type_check_only
class ListCutoverJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCutoverJobsResponse: ...

@typing.type_check_only
class ListDatacenterConnectorsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDatacenterConnectorsResponse: ...

@typing.type_check_only
class ListGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGroupsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListMigratingVmsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMigratingVmsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListReplicationCyclesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReplicationCyclesResponse: ...

@typing.type_check_only
class ListSourcesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSourcesResponse: ...

@typing.type_check_only
class ListTargetProjectsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTargetProjectsResponse: ...

@typing.type_check_only
class ListUtilizationReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUtilizationReportsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class MigratingVmHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MigratingVm: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ReplicationCycleHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReplicationCycle: ...

@typing.type_check_only
class SourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Source: ...

@typing.type_check_only
class TargetProjectHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TargetProject: ...

@typing.type_check_only
class UtilizationReportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UtilizationReport: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BeyondCorpResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class InsightsResource(googleapiclient.discovery.Resource):
                def configuredInsight(
                    self,
                    *,
                    insight: str,
                    aggregation: typing_extensions.Literal[
                        "AGGREGATION_UNSPECIFIED",
                        "HOURLY",
                        "DAILY",
                        "WEEKLY",
                        "MONTHLY",
                        "CUSTOM_DATE_RANGE",
                    ] = ...,
                    customGrouping_fieldFilter: str = ...,
                    customGrouping_groupFields: str | _list[str] = ...,
                    endTime: str = ...,
                    fieldFilter: str = ...,
                    group: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    startTime: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest: ...
                def configuredInsight_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponse,
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest | None: ...
                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "INSIGHT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "INSIGHT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponse,
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest | None: ...

            def insights(self) -> InsightsResource: ...

        def locations(self) -> LocationsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AppConnectionsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection = ...,
                    appConnectionId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponse,
                ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection = ...,
                    allowMissing: bool = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def resolve(
                    self,
                    *,
                    parent: str,
                    appConnectorId: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseHttpRequest: ...
                def resolve_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponse,
                ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class AppConnectorsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector = ...,
                    appConnectorId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponse,
                ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def reportStatus(
                    self,
                    *,
                    appConnector: str,
                    body: GoogleCloudBeyondcorpAppconnectorsV1alphaReportStatusRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def resolveInstanceConfig(
                    self, *, appConnector: str, **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponseHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class AppGatewaysResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: AppGateway = ...,
                    appGatewayId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AppGatewayHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListAppGatewaysResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListAppGatewaysResponseHttpRequest,
                    previous_response: ListAppGatewaysResponse,
                ) -> ListAppGatewaysResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ApplicationsResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ClientConnectorServicesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: ClientConnectorService = ...,
                    clientConnectorServiceId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ClientConnectorServiceHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListClientConnectorServicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClientConnectorServicesResponseHttpRequest,
                    previous_response: ListClientConnectorServicesResponse,
                ) -> ListClientConnectorServicesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: ClientConnectorService = ...,
                    allowMissing: bool = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ClientGatewaysResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: ClientGateway = ...,
                    clientGatewayId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ClientGatewayHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListClientGatewaysResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClientGatewaysResponseHttpRequest,
                    previous_response: ListClientGatewaysResponse,
                ) -> ListClientGatewaysResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ConnectionsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Connection = ...,
                    connectionId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ConnectionHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListConnectionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListConnectionsResponseHttpRequest,
                    previous_response: ListConnectionsResponse,
                ) -> ListConnectionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Connection = ...,
                    allowMissing: bool = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def resolve(
                    self,
                    *,
                    parent: str,
                    connectorId: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ResolveConnectionsResponseHttpRequest: ...
                def resolve_next(
                    self,
                    previous_request: ResolveConnectionsResponseHttpRequest,
                    previous_response: ResolveConnectionsResponse,
                ) -> ResolveConnectionsResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class ConnectorsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Connector = ...,
                    connectorId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ConnectorHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListConnectorsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListConnectorsResponseHttpRequest,
                    previous_response: ListConnectorsResponse,
                ) -> ListConnectorsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Connector = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def reportStatus(
                    self,
                    *,
                    connector: str,
                    body: ReportStatusRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def resolveInstanceConfig(
                    self, *, connector: str, **kwargs: typing.Any
                ) -> ResolveInstanceConfigResponseHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class InsightsResource(googleapiclient.discovery.Resource):
                def configuredInsight(
                    self,
                    *,
                    insight: str,
                    aggregation: typing_extensions.Literal[
                        "AGGREGATION_UNSPECIFIED",
                        "HOURLY",
                        "DAILY",
                        "WEEKLY",
                        "MONTHLY",
                        "CUSTOM_DATE_RANGE",
                    ] = ...,
                    customGrouping_fieldFilter: str = ...,
                    customGrouping_groupFields: str | _list[str] = ...,
                    endTime: str = ...,
                    fieldFilter: str = ...,
                    group: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    startTime: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest: ...
                def configuredInsight_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponse,
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest | None: ...
                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "INSIGHT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "INSIGHT_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponse,
                ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest | None: ...

            @typing.type_check_only
            class NetConnectionsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnection = ...,
                    netConnectionId: str = ...,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    requestId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnectionHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponseHttpRequest,
                    previous_response: GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponse,
                ) -> GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnection = ...,
                    allowMissing: bool = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: GoogleIamV1TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: GoogleLongrunningCancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudLocationLocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudLocationListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudLocationListLocationsResponseHttpRequest,
                previous_response: GoogleCloudLocationListLocationsResponse,
            ) -> GoogleCloudLocationListLocationsResponseHttpRequest | None: ...
            def appConnections(self) -> AppConnectionsResource: ...
            def appConnectors(self) -> AppConnectorsResource: ...
            def appGateways(self) -> AppGatewaysResource: ...
            def applications(self) -> ApplicationsResource: ...
            def clientConnectorServices(self) -> ClientConnectorServicesResource: ...
            def clientGateways(self) -> ClientGatewaysResource: ...
            def connections(self) -> ConnectionsResource: ...
            def connectors(self) -> ConnectorsResource: ...
            def insights(self) -> InsightsResource: ...
            def netConnections(self) -> NetConnectionsResource: ...
            def operations(self) -> OperationsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class AppGatewayHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AppGateway: ...

@typing.type_check_only
class ClientConnectorServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientConnectorService: ...

@typing.type_check_only
class ClientGatewayHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientGateway: ...

@typing.type_check_only
class ConnectionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Connection: ...

@typing.type_check_only
class ConnectorHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Connector: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnectionHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaAppConnection: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaListAppConnectionsResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectionsV1alphaResolveAppConnectionsResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnectorHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaAppConnector: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaListAppConnectorsResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpAppconnectorsV1alphaResolveInstanceConfigResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpNetconnectionsV1alphaListNetConnectionsResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnectionHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpNetconnectionsV1alphaNetConnection: ...

@typing.type_check_only
class GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaConfiguredInsightResponse: ...

@typing.type_check_only
class GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsightHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaInsight: ...

@typing.type_check_only
class GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudBeyondcorpSaasplatformInsightsV1alphaListInsightsResponse: ...

@typing.type_check_only
class GoogleCloudLocationListLocationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudLocationListLocationsResponse: ...

@typing.type_check_only
class GoogleCloudLocationLocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudLocationLocation: ...

@typing.type_check_only
class GoogleIamV1PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1Policy: ...

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1TestIamPermissionsResponse: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class ListAppGatewaysResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAppGatewaysResponse: ...

@typing.type_check_only
class ListClientConnectorServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientConnectorServicesResponse: ...

@typing.type_check_only
class ListClientGatewaysResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientGatewaysResponse: ...

@typing.type_check_only
class ListConnectionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectionsResponse: ...

@typing.type_check_only
class ListConnectorsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectorsResponse: ...

@typing.type_check_only
class ResolveConnectionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ResolveConnectionsResponse: ...

@typing.type_check_only
class ResolveInstanceConfigResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ResolveInstanceConfigResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcknowledgeRequest(typing_extensions.TypedDict, total=False):
    ackIds: _list[str]

@typing.type_check_only
class BigQueryConfig(typing_extensions.TypedDict, total=False):
    dropUnknownFields: bool
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "ACTIVE",
        "PERMISSION_DENIED",
        "NOT_FOUND",
        "SCHEMA_MISMATCH",
    ]
    table: str
    useTopicSchema: bool
    writeMetadata: bool

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CreateSnapshotRequest(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]
    subscription: str

@typing.type_check_only
class DeadLetterPolicy(typing_extensions.TypedDict, total=False):
    deadLetterTopic: str
    maxDeliveryAttempts: int

@typing.type_check_only
class DetachSubscriptionResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExpirationPolicy(typing_extensions.TypedDict, total=False):
    ttl: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ListSchemasResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    schemas: _list[Schema]

@typing.type_check_only
class ListSnapshotsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    snapshots: _list[Snapshot]

@typing.type_check_only
class ListSubscriptionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    subscriptions: _list[Subscription]

@typing.type_check_only
class ListTopicSnapshotsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    snapshots: _list[str]

@typing.type_check_only
class ListTopicSubscriptionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    subscriptions: _list[str]

@typing.type_check_only
class ListTopicsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    topics: _list[Topic]

@typing.type_check_only
class MessageStoragePolicy(typing_extensions.TypedDict, total=False):
    allowedPersistenceRegions: _list[str]

@typing.type_check_only
class ModifyAckDeadlineRequest(typing_extensions.TypedDict, total=False):
    ackDeadlineSeconds: int
    ackIds: _list[str]

@typing.type_check_only
class ModifyPushConfigRequest(typing_extensions.TypedDict, total=False):
    pushConfig: PushConfig

@typing.type_check_only
class OidcToken(typing_extensions.TypedDict, total=False):
    audience: str
    serviceAccountEmail: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PublishRequest(typing_extensions.TypedDict, total=False):
    messages: _list[PubsubMessage]

@typing.type_check_only
class PublishResponse(typing_extensions.TypedDict, total=False):
    messageIds: _list[str]

@typing.type_check_only
class PubsubMessage(typing_extensions.TypedDict, total=False):
    attributes: dict[str, typing.Any]
    data: str
    messageId: str
    orderingKey: str
    publishTime: str

@typing.type_check_only
class PullRequest(typing_extensions.TypedDict, total=False):
    maxMessages: int
    returnImmediately: bool

@typing.type_check_only
class PullResponse(typing_extensions.TypedDict, total=False):
    receivedMessages: _list[ReceivedMessage]

@typing.type_check_only
class PushConfig(typing_extensions.TypedDict, total=False):
    attributes: dict[str, typing.Any]
    oidcToken: OidcToken
    pushEndpoint: str

@typing.type_check_only
class ReceivedMessage(typing_extensions.TypedDict, total=False):
    ackId: str
    deliveryAttempt: int
    message: PubsubMessage

@typing.type_check_only
class RetryPolicy(typing_extensions.TypedDict, total=False):
    maximumBackoff: str
    minimumBackoff: str

@typing.type_check_only
class Schema(typing_extensions.TypedDict, total=False):
    definition: str
    name: str
    revisionCreateTime: str
    revisionId: str
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "PROTOCOL_BUFFER", "AVRO"]

@typing.type_check_only
class SchemaSettings(typing_extensions.TypedDict, total=False):
    encoding: typing_extensions.Literal["ENCODING_UNSPECIFIED", "JSON", "BINARY"]
    firstRevisionId: str
    lastRevisionId: str
    schema: str

@typing.type_check_only
class SeekRequest(typing_extensions.TypedDict, total=False):
    snapshot: str
    time: str

@typing.type_check_only
class SeekResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class Snapshot(typing_extensions.TypedDict, total=False):
    expireTime: str
    labels: dict[str, typing.Any]
    name: str
    topic: str

@typing.type_check_only
class Subscription(typing_extensions.TypedDict, total=False):
    ackDeadlineSeconds: int
    bigqueryConfig: BigQueryConfig
    deadLetterPolicy: DeadLetterPolicy
    detached: bool
    enableExactlyOnceDelivery: bool
    enableMessageOrdering: bool
    expirationPolicy: ExpirationPolicy
    filter: str
    labels: dict[str, typing.Any]
    messageRetentionDuration: str
    name: str
    pushConfig: PushConfig
    retainAckedMessages: bool
    retryPolicy: RetryPolicy
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "RESOURCE_ERROR"]
    topic: str
    topicMessageRetentionDuration: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class Topic(typing_extensions.TypedDict, total=False):
    kmsKeyName: str
    labels: dict[str, typing.Any]
    messageRetentionDuration: str
    messageStoragePolicy: MessageStoragePolicy
    name: str
    satisfiesPzs: bool
    schemaSettings: SchemaSettings

@typing.type_check_only
class UpdateSnapshotRequest(typing_extensions.TypedDict, total=False):
    snapshot: Snapshot
    updateMask: str

@typing.type_check_only
class UpdateSubscriptionRequest(typing_extensions.TypedDict, total=False):
    subscription: Subscription
    updateMask: str

@typing.type_check_only
class UpdateTopicRequest(typing_extensions.TypedDict, total=False):
    topic: Topic
    updateMask: str

@typing.type_check_only
class ValidateMessageRequest(typing_extensions.TypedDict, total=False):
    encoding: typing_extensions.Literal["ENCODING_UNSPECIFIED", "JSON", "BINARY"]
    message: str
    name: str
    schema: Schema

@typing.type_check_only
class ValidateMessageResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ValidateSchemaRequest(typing_extensions.TypedDict, total=False):
    schema: Schema

@typing.type_check_only
class ValidateSchemaResponse(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class LibraryagentResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ShelvesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class BooksResource(googleapiclient.discovery.Resource):
            def borrow(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleExampleLibraryagentV1BookHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleExampleLibraryagentV1BookHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleExampleLibraryagentV1ListBooksResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleExampleLibraryagentV1ListBooksResponseHttpRequest,
                previous_response: GoogleExampleLibraryagentV1ListBooksResponse,
            ) -> GoogleExampleLibraryagentV1ListBooksResponseHttpRequest | None: ...
            def return_(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleExampleLibraryagentV1BookHttpRequest: ...

        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleExampleLibraryagentV1ShelfHttpRequest: ...
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> GoogleExampleLibraryagentV1ListShelvesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleExampleLibraryagentV1ListShelvesResponseHttpRequest,
            previous_response: GoogleExampleLibraryagentV1ListShelvesResponse,
        ) -> GoogleExampleLibraryagentV1ListShelvesResponseHttpRequest | None: ...
        def books(self) -> BooksResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def shelves(self) -> ShelvesResource: ...

@typing.type_check_only
class GoogleExampleLibraryagentV1BookHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleExampleLibraryagentV1Book: ...

@typing.type_check_only
class GoogleExampleLibraryagentV1ListBooksResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleExampleLibraryagentV1ListBooksResponse: ...

@typing.type_check_only
class GoogleExampleLibraryagentV1ListShelvesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleExampleLibraryagentV1ListShelvesResponse: ...

@typing.type_check_only
class GoogleExampleLibraryagentV1ShelfHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleExampleLibraryagentV1Shelf: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudBillingBudgetsV1Budget(typing_extensions.TypedDict, total=False):
    amount: GoogleCloudBillingBudgetsV1BudgetAmount
    budgetFilter: GoogleCloudBillingBudgetsV1Filter
    displayName: str
    etag: str
    name: str
    notificationsRule: GoogleCloudBillingBudgetsV1NotificationsRule
    thresholdRules: _list[GoogleCloudBillingBudgetsV1ThresholdRule]

@typing.type_check_only
class GoogleCloudBillingBudgetsV1BudgetAmount(typing_extensions.TypedDict, total=False):
    lastPeriodAmount: GoogleCloudBillingBudgetsV1LastPeriodAmount
    specifiedAmount: GoogleTypeMoney

@typing.type_check_only
class GoogleCloudBillingBudgetsV1CustomPeriod(typing_extensions.TypedDict, total=False):
    endDate: GoogleTypeDate
    startDate: GoogleTypeDate

@typing.type_check_only
class GoogleCloudBillingBudgetsV1Filter(typing_extensions.TypedDict, total=False):
    calendarPeriod: typing_extensions.Literal[
        "CALENDAR_PERIOD_UNSPECIFIED", "MONTH", "QUARTER", "YEAR"
    ]
    creditTypes: _list[str]
    creditTypesTreatment: typing_extensions.Literal[
        "CREDIT_TYPES_TREATMENT_UNSPECIFIED",
        "INCLUDE_ALL_CREDITS",
        "EXCLUDE_ALL_CREDITS",
        "INCLUDE_SPECIFIED_CREDITS",
    ]
    customPeriod: GoogleCloudBillingBudgetsV1CustomPeriod
    labels: dict[str, typing.Any]
    projects: _list[str]
    services: _list[str]
    subaccounts: _list[str]

@typing.type_check_only
class GoogleCloudBillingBudgetsV1LastPeriodAmount(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudBillingBudgetsV1ListBudgetsResponse(
    typing_extensions.TypedDict, total=False
):
    budgets: _list[GoogleCloudBillingBudgetsV1Budget]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudBillingBudgetsV1NotificationsRule(
    typing_extensions.TypedDict, total=False
):
    disableDefaultIamRecipients: bool
    monitoringNotificationChannels: _list[str]
    pubsubTopic: str
    schemaVersion: str

@typing.type_check_only
class GoogleCloudBillingBudgetsV1ThresholdRule(
    typing_extensions.TypedDict, total=False
):
    spendBasis: typing_extensions.Literal[
        "BASIS_UNSPECIFIED", "CURRENT_SPEND", "FORECASTED_SPEND"
    ]
    thresholdPercent: float

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleTypeDate(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class GoogleTypeMoney(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AggregateMetrics(typing_extensions.TypedDict, total=False):
    answeredCallsCount: int
    endDate: Date
    hourlyMetrics: _list[HourlyMetrics]
    missedCallsCount: int
    startDate: Date
    weekdayMetrics: _list[WeekDayMetrics]

@typing.type_check_only
class BusinessCallsInsights(typing_extensions.TypedDict, total=False):
    aggregateMetrics: AggregateMetrics
    metricType: typing_extensions.Literal["METRIC_TYPE_UNSPECIFIED", "AGGREGATE_COUNT"]
    name: str

@typing.type_check_only
class BusinessCallsSettings(typing_extensions.TypedDict, total=False):
    callsState: typing_extensions.Literal[
        "CALLS_STATE_UNSPECIFIED", "ENABLED", "DISABLED"
    ]
    consentTime: str
    name: str

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class HourlyMetrics(typing_extensions.TypedDict, total=False):
    hour: int
    missedCallsCount: int

@typing.type_check_only
class ListBusinessCallsInsightsResponse(typing_extensions.TypedDict, total=False):
    businessCallsInsights: _list[BusinessCallsInsights]
    nextPageToken: str

@typing.type_check_only
class WeekDayMetrics(typing_extensions.TypedDict, total=False):
    day: typing_extensions.Literal[
        "DAY_OF_WEEK_UNSPECIFIED",
        "MONDAY",
        "TUESDAY",
        "WEDNESDAY",
        "THURSDAY",
        "FRIDAY",
        "SATURDAY",
        "SUNDAY",
    ]
    missedCallsCount: int



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Annotation(typing_extensions.TypedDict, total=False):
    attributes: Attributes
    description: TruncatableString

@typing.type_check_only
class AttributeValue(typing_extensions.TypedDict, total=False):
    boolValue: bool
    intValue: str
    stringValue: TruncatableString

@typing.type_check_only
class Attributes(typing_extensions.TypedDict, total=False):
    attributeMap: dict[str, typing.Any]
    droppedAttributesCount: int

@typing.type_check_only
class BatchWriteSpansRequest(typing_extensions.TypedDict, total=False):
    spans: _list[Span]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Link(typing_extensions.TypedDict, total=False):
    attributes: Attributes
    spanId: str
    traceId: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "CHILD_LINKED_SPAN", "PARENT_LINKED_SPAN"
    ]

@typing.type_check_only
class Links(typing_extensions.TypedDict, total=False):
    droppedLinksCount: int
    link: _list[Link]

@typing.type_check_only
class MessageEvent(typing_extensions.TypedDict, total=False):
    compressedSizeBytes: str
    id: str
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "SENT", "RECEIVED"]
    uncompressedSizeBytes: str

@typing.type_check_only
class Module(typing_extensions.TypedDict, total=False):
    buildId: TruncatableString
    module: TruncatableString

@typing.type_check_only
class Span(typing_extensions.TypedDict, total=False):
    attributes: Attributes
    childSpanCount: int
    displayName: TruncatableString
    endTime: str
    links: Links
    name: str
    parentSpanId: str
    sameProcessAsParentSpan: bool
    spanId: str
    spanKind: typing_extensions.Literal[
        "SPAN_KIND_UNSPECIFIED", "INTERNAL", "SERVER", "CLIENT", "PRODUCER", "CONSUMER"
    ]
    stackTrace: StackTrace
    startTime: str
    status: Status
    timeEvents: TimeEvents

@typing.type_check_only
class StackFrame(typing_extensions.TypedDict, total=False):
    columnNumber: str
    fileName: TruncatableString
    functionName: TruncatableString
    lineNumber: str
    loadModule: Module
    originalFunctionName: TruncatableString
    sourceVersion: TruncatableString

@typing.type_check_only
class StackFrames(typing_extensions.TypedDict, total=False):
    droppedFramesCount: int
    frame: _list[StackFrame]

@typing.type_check_only
class StackTrace(typing_extensions.TypedDict, total=False):
    stackFrames: StackFrames
    stackTraceHashId: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TimeEvent(typing_extensions.TypedDict, total=False):
    annotation: Annotation
    messageEvent: MessageEvent
    time: str

@typing.type_check_only
class TimeEvents(typing_extensions.TypedDict, total=False):
    droppedAnnotationsCount: int
    droppedMessageEventsCount: int
    timeEvent: _list[TimeEvent]

@typing.type_check_only
class TruncatableString(typing_extensions.TypedDict, total=False):
    truncatedByteCount: int
    value: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class RecaptchaEnterpriseResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AssessmentsResource(googleapiclient.discovery.Resource):
            def annotate(
                self,
                *,
                name: str,
                body: GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponseHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudRecaptchaenterpriseV1Assessment = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1AssessmentHttpRequest: ...

        @typing.type_check_only
        class KeysResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudRecaptchaenterpriseV1Key = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1KeyHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1KeyHttpRequest: ...
            def getMetrics(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1MetricsHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1ListKeysResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudRecaptchaenterpriseV1ListKeysResponseHttpRequest,
                previous_response: GoogleCloudRecaptchaenterpriseV1ListKeysResponse,
            ) -> GoogleCloudRecaptchaenterpriseV1ListKeysResponseHttpRequest | None: ...
            def migrate(
                self,
                *,
                name: str,
                body: GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1KeyHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudRecaptchaenterpriseV1Key = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1KeyHttpRequest: ...
            def retrieveLegacySecretKey(
                self, *, key: str, **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponseHttpRequest: ...

        @typing.type_check_only
        class RelatedaccountgroupmembershipsResource(
            googleapiclient.discovery.Resource
        ):
            def search(
                self,
                *,
                project: str,
                body: GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponseHttpRequest: ...
            def search_next(
                self,
                previous_request: GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponseHttpRequest,
                previous_response: GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse,
            ) -> GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponseHttpRequest | None: ...

        @typing.type_check_only
        class RelatedaccountgroupsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class MembershipsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponseHttpRequest,
                    previous_response: GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse,
                ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponseHttpRequest | None: ...

            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponseHttpRequest,
                previous_response: GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse,
            ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponseHttpRequest | None: ...
            def memberships(self) -> MembershipsResource: ...

        def assessments(self) -> AssessmentsResource: ...
        def keys(self) -> KeysResource: ...
        def relatedaccountgroupmemberships(
            self,
        ) -> RelatedaccountgroupmembershipsResource: ...
        def relatedaccountgroups(self) -> RelatedaccountgroupsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1AssessmentHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1Assessment: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1KeyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1Key: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1ListKeysResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1ListKeysResponse: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1MetricsHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1Metrics: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse: ...

@typing.type_check_only
class GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ApiDataRow(typing_extensions.TypedDict, total=False):
    clicks: float
    ctr: float
    impressions: float
    keys: _list[str]
    position: float

@typing.type_check_only
class ApiDimensionFilter(typing_extensions.TypedDict, total=False):
    dimension: str
    expression: str
    operator: str

@typing.type_check_only
class ApiDimensionFilterGroup(typing_extensions.TypedDict, total=False):
    filters: _list[ApiDimensionFilter]
    groupType: str

@typing.type_check_only
class SearchAnalyticsQueryRequest(typing_extensions.TypedDict, total=False):
    aggregationType: str
    dataState: str
    dimensionFilterGroups: _list[ApiDimensionFilterGroup]
    dimensions: _list[str]
    endDate: str
    rowLimit: int
    searchType: str
    startDate: str
    startRow: int

@typing.type_check_only
class SearchAnalyticsQueryResponse(typing_extensions.TypedDict, total=False):
    responseAggregationType: str
    rows: _list[ApiDataRow]

@typing.type_check_only
class SitemapsListResponse(typing_extensions.TypedDict, total=False):
    sitemap: _list[WmxSitemap]

@typing.type_check_only
class SitesListResponse(typing_extensions.TypedDict, total=False):
    siteEntry: _list[WmxSite]

@typing.type_check_only
class WmxSite(typing_extensions.TypedDict, total=False):
    permissionLevel: str
    siteUrl: str

@typing.type_check_only
class WmxSitemap(typing_extensions.TypedDict, total=False):
    contents: _list[WmxSitemapContent]
    errors: str
    isPending: bool
    isSitemapsIndex: bool
    lastDownloaded: str
    lastSubmitted: str
    path: str
    type: str
    warnings: str

@typing.type_check_only
class WmxSitemapContent(typing_extensions.TypedDict, total=False):
    indexed: str
    submitted: str
    type: str
